/***************************************************************************
 *   Copyright (C) 2004 by James Thorniley                                 *
 *   james@uncommonlygood.co.uk                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "driveselectpage.h"
#include "scanbusthread.h"

#include <qlayout.h>
#include <klistview.h>
#include <qlabel.h>
#include <klocale.h>
#include <kprocess.h>
#include <qapplication.h>
#include <qregexp.h>
#include <kdebug.h>
#include <kprogress.h>
#include <kconfig.h>
#include <qtimer.h>
#include <qwhatsthis.h>
#include <qpushbutton.h>
#include <qvaluelist.h>

DriveSelectPage::DriveSelectPage(KConfig *config, KWizard *parentWizard, QWidget *parent, const char *name)
 : QWidget(parent, name)
{
  m_config = config;

  this->setMinimumHeight( 200 );
  this->setMinimumWidth( 200 );

  m_instructions = new QLabel( this, 0);
  m_instructions->setText(i18n("Please wait while KDE scans for CD/DVD devices") );
  m_instructions->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Minimum );
  
  m_listView = new KListView( this);
  m_listView->addColumn( i18n("Device name"));
  m_listView->addColumn( i18n("Type") );
  m_listView->addColumn( i18n("File name" ) );
  m_listView->setAllColumnsShowFocus( true );
  m_listView->setSelectionMode( QListView::Single );
  m_listView->setSorting( -1 );
  m_listView->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
  m_listView->setHidden(true);
  
  m_progress = new KProgress( this );
  m_progress->setTotalSteps( 100 );
  m_progress->setProgress( 99 );
  m_progress->setTextEnabled( false );
  
  m_layout = new QVBoxLayout( this,5 );
  m_layout->addStretch();
  m_layout->addWidget( m_instructions );
  m_layout->addWidget( m_progress );
  m_layout->addWidget( m_listView );
  m_layout->addStretch();
  
  QWhatsThis::add( m_listView, i18n( "<p>Select a device from this list.<p><b>Device name</b> is the description this device reported for itself.<p><b>Type</b> specifies whether this is a CD or DVD burner.<p><b>File name</b> is the UNIX file name associated with this device. If you don't know what this means, don't worry. It's not important unless you have two identical devices and you need to distinguish between them, in which case you'll have to find out somehow which device corresponds to which file name." ) );
  m_wizard = parentWizard;
  
  m_timer = new QTimer();
  connect( m_timer, SIGNAL( timeout() ),
           this, SLOT( checkScanFinished() ) );
  m_timer->start( 1000 );
  
  m_scanBusThread = new ScanBusThread();
  m_scanBusThread->start();
}


void DriveSelectPage::saveSettings()
{
  int i;
  for( i = 0; m_scanBusThread->deviceList()[i].fileName != m_listView->currentItem()->text(2); i++ ); 
  
  m_config->writeEntry( "file", m_scanBusThread->deviceList()[i].fileName );
  m_config->writeEntry( "cdr", m_scanBusThread->deviceList()[i].CDR );
  m_config->writeEntry( "cdrw", m_scanBusThread->deviceList()[i].CDRW );
  m_config->writeEntry( "dvd-r", m_scanBusThread->deviceList()[i].DVDMR );
  m_config->writeEntry( "dvd-rwresovr", m_scanBusThread->deviceList()[i].DVDMRWrovr );
  m_config->writeEntry( "dvd-rwresrec", m_scanBusThread->deviceList()[i].DVDMRWrrec );
  m_config->writeEntry( "dvd-ram", m_scanBusThread->deviceList()[i].DVDRAM );
  m_config->writeEntry( "dvd+r", m_scanBusThread->deviceList()[i].DVDPR );
  m_config->writeEntry( "dvd+rw", m_scanBusThread->deviceList()[i].DVDPRW );
  m_config->writeEntry( "isdvdr", m_scanBusThread->deviceList()[i].isDVDR );
  m_config->sync();
  
}
DriveSelectPage::~DriveSelectPage()
{
}

void DriveSelectPage::checkScanFinished()
{
  if( m_scanBusThread->finished() )
  {
    delete m_timer;
    
    m_instructions->setText( i18n( "Please choose the device you would like to use from the list below" ) );
    m_progress->setHidden( true );
    m_listView->setHidden( false );
    
    QValueList<Device>::Iterator dev;
    for( dev = m_scanBusThread->deviceList().begin(); dev != m_scanBusThread->deviceList().end(); dev++ )
    {     
      if( (*dev).CDR | (*dev).isDVDR )
        new KListViewItem( m_listView,
                           (*dev).desc,
                           (*dev).isDVDR ? i18n( "DVD burner" ) : i18n( "CD burner" ),
                           (*dev).fileName);
  
    }
  }
}
#include "driveselectpage.moc"
